@@ -618,7 +618,7 @@ class TestrailLibrary:
                 logger.info(f'Deleting attachment {attachment["name"]} from run {run_id}')
                 try:
                     response = self.delete_attachment(attachment)
-                    deleted.append(attachment["name"])
+                    deleted.append(attachment)
                 except Exception as e:
                     logger.error(e)  
         logger.info(deleted)      
