@@ -693,18 +693,17 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_post')
     @patch('TestrailLibrary.apiclient.Apiclient.send_get')
     def test_delete_attachments_cleanup(self, mock_get, mock_post):
-        
         run = RunsResponse(1).runs[0]
         attachments = AttachmentsResponse(10)
         mock_get.return_value = attachments.get 
         attachments_sorted = sorted(attachments.attachments, key=lambda x: x.get("created_on"))
-        exp_response = [attachments_sorted[i] for i in range(len(attachments_sorted[:-7]))]
-        expected_response = list(map(lambda x: x.get("name"), exp_response))
+        expected_response = [attachments_sorted[i] for i in range(len(attachments_sorted[:-7]))]
         deleted_response = None
         mock_post.return_value = deleted_response
         res = self.tr.delete_attachments_cleanup(run.get("id"))
         self.assertEqual(res, expected_response)
 
+
 if __name__ == "__main__":
     unittest.main()
         
